@@ -8,6 +8,7 @@ public enum Annotation {
 
   BandwidthFile("@type bandwidth-file 1.0\n"),
   BridgeExtraInfo("@type bridge-extra-info 1.3\n"),
+  BridgePoolAssignment("@type bridge-pool-assignment 1.0\n"),
   BridgeServer("@type bridge-server-descriptor 1.2\n"),
   Cert("@type dir-key-certificate-3 1.0\n"),
   Consensus("@type network-status-consensus-3 1.0\n"),
@@ -18,7 +19,8 @@ public enum Annotation {
   Server("@type server-descriptor 1.0\n"),
   Status("@type bridge-network-status 1.2\n"),
   OnionPerf("@type torperf 1.1\n"),
-  Vote("@type network-status-vote-3 1.0\n");
+  Vote("@type network-status-vote-3 1.0\n"),
+  SnowflakeStats("@type snowflake-stats 1.0\n");
 
   private final String annotation;
   private final byte[] bytes;
